@@ -25,11 +25,9 @@
 #include <time.h>
 
 #include <libnotify/notification.h>
+#include <libnotify/notify-enum-types.h>
 
-/**************************************************************************/
-/** @name libnotify Base API                                              */
-/**************************************************************************/
-/*@{*/
+G_BEGIN_DECLS
 
 /**
  * Initializes the notifications library.
@@ -74,10 +72,10 @@ GList *notify_get_server_caps(void);
  *
  * The strings returned must be freed.
  *
- * @param ret_name     The returned product name of the server.
- * @param ret_vendor   The returned vendor.
- * @param ret_version  The returned server version.
- * @param ret_spec_ver The returned specification version supported.
+ * @param ret_name         The returned product name of the server.
+ * @param ret_vendor       The returned vendor.
+ * @param ret_version      The returned server version.
+ * @param ret_spec_version The returned specification version supported.
  *
  * @return TRUE if the call succeeded, or FALSE if there were errors.
  */
@@ -86,6 +84,6 @@ gboolean notify_get_server_info(char **ret_name,
 								char **ret_version,
 								char **ret_spec_version);
 
-/*@}*/
+G_END_DECLS
 
 #endif /* _LIBNOTIFY_NOTIFY_H_ */
